*--------------------------------------------------------------------------*;
%let ProgramName = format ;
%let Extension   = sas ;
%let Version     = 3.5 ;
%let Root        = /data/cahpsmmc/analysis_program/version 3.5 ;
%let ProgramPath = /programs/ ;
%let Created     = 24 Aug 2005 ;
%let Author      = Matthew J. Cioffi ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
      NONE
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| What are the permanent output datasets created by the program or where   |
| are all the datasets stored if there are many.                           |
      formats.sas7bcat
*--------------------------------------------------------------------------*;
 
***********
* Purpose *
   Create permanent formats for the test data set included with
   the CAHPS Analysis Program.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;


*--------------------------------------------------------------------------*
| Macro Variables                                                          |
*--------------------------------------------------------------------------*;
%let Filename    = &ProgramName..&Extension  ; 

*--------------------------------------------------------------------------*
| Set up the environment, library names, file names, options...            |
*--------------------------------------------------------------------------*;
libname  cahpsmmc "&root./sasdata/" ;
libname  cahp_ori "&root./sasdata/original/" ;
libname  cahp_fmt "&root./sascatalog/" ;

filename outfile  "&root./output/&ProgramName..txt" ;
filename logfile  "&root./output/logs/&ProgramName..log" ;



proc printto print = outfile new
             log   = logfile new ;
run ;

*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox (logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
        fmtsearch = (cahp_fmt)
;

*--------------------------------------------------------------------------*
| Clear titles and footnotes.                                              |
*--------------------------------------------------------------------------*;

title ;
footnote;

*--------------------------------------------------------------------------*
| Begin Programming Code                                                   |
*--------------------------------------------------------------------------*;


proc format library = cahp_fmt
            page
            fmtlib ;
 title "CAHPS Survey Formats for TEST Data Set Version &version " ;

  value ynb
         . = 'Missing         '
         1 = 'Yes             '
         2 = 'No              '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value yna
         . = 'Missing         '
         1 = 'Yes             '
         0 = 'No              '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value triprob
         . = 'Missing         '
         1 = 'A Big Problem   '
         2 = 'A Small Problem '
         3 = 'Not a Problem   '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value often
         . = 'Missing         '
         1 = 'Never           '
         2 = 'Sometimes       '
         3 = 'Usually         '
         4 = 'Always          '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value rating
         . = 'Missing         '
         0 = '0, worst        '
         1 = '1               '
         2 = '2               '
         3 = '3               '
         4 = '4               '
         5 = '5               '
         6 = '6               '
         7 = '7               '
         8 = '8               '
         9 = '9               '
        10 = '10, best        '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value times
         . = 'Missing         '
         0 = 'None            '
         1 = '1 time          '
         2 = '2 times         '
         3 = '3 times         '
         4 = '4 times         '
         5 = '5 to 9 times    '
         6 = '10 or more times'
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value ratinge
         . = 'Missing         '
         1 = 'Excellent       '
         2 = 'Very good       '
         3 = 'Good            '
         4 = 'Fair            '
         5 = 'Poor            '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value age
         . = 'Missing         '
         1 = '18 to 24        '
         2 = '25 to 34        '
         3 = '35 to 44        '
         4 = '45 to 54        '
         5 = '55 or 64        '
         6 = '65 to 74        '
         7 = '75 or older     '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value gender
         . = 'Missing         '
         1 = 'Male            '
         2 = 'Female          '
        98 = 'Inapplicable    '
        99 = 'No Answer Given '
  ;
  value plan
         . = 'Missing         '
         1 = 'HMO_A_Urban     '
         2 = 'HMO_B_Urban     '
         3 = 'HMO_C_Urban     '
         4 = 'HMO_B_Rural     '
         5 = 'HMO_C_Rural     '
  ;
run;


*--------------------------------------------------------------------------*
| End Programming Code                                                     |
| Clear titles and footnotes.                                              |
| Reset the log file and output file to their defaults.                    |
| Clear the filenames used.                                                |
*--------------------------------------------------------------------------*;

title ;
footnote;


proc printto ;
run ;

filename outfile  clear ;
filename logfile  clear ;


%nowbox (logtext = End &FileName version &Version ) ;
