/*
File Name  :  make_plandtal_dat.sas
Location   :  elixir:/data/mcahps/analysis_program/version4.1/programs/
Created    :  12-July-1999
Author     :  Matthew J. Cioffi
Type       :  Program
Purpose    :
   Create a basic detail file that can be used to gather the plan
   information.

Usage      :  Syntax for use and/or examples
Input      :  Input parameters if any
Output     :  Output returned from module
Limits     :  Note any known limitations

---------------------------------------------------------------------------
Updated    :  dd-mmm-yyyy
by Whom    :
Reason     :

---------------------------------------------------------------------------
*/

*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox (logtext= Begin make_plandtal_dat.sas) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 55
        linesize = 80
        nomprint
        nomlogic 
        pageno   = 1
        nonumber
        nodate
        ;
run ;


*--------------------------------------------------------------------------*
| Macro Variables                                                          |
|    root01   - Root path for libraries and files.                         |
*--------------------------------------------------------------------------*;

%let root01   = /data/cahpsmmc/analysis_program/version4.1/;

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
*--------------------------------------------------------------------------*;

libname in        "&root01.sasdata/" ;
libname out       "&root01.sasdata/" ;
libname library   "&root01.sascatalog/formats/" ;
filename plan_dat "&root01.data_other/plandtal.dat" ;

run ;



*--------------------------------------------------------------------------*
| Sort the test data set and keep only unique values of the plan numbers.  |
*--------------------------------------------------------------------------*;

proc sort data = in.test21 ( keep = planid 
                             where = ( planid ne . ))
          out  = test 
          nodupkey
          ;
   by planid ;
run ;


*--------------------------------------------------------------------------*
| Create a text file that can be read in by the CAHPS macro.               |
| The data must contain the following four fields in order.                |
| None of the values can be missing.                                       |
|    Plan Strata Name - Name or ID for the Plan or Plan Strata             |
|    Plan Name        - Name or ID for the Plan, may be the same as Strata |
|    Strata Weight    - Weight value given to this strata                  |
|    Subset Name      - Name or Code for the subsetting option             |
*--------------------------------------------------------------------------*;

data _null_ ;
   set test ;
   file plan_dat ;

   length planstra $ 20 
          planname $ 20
          stratwgt $ 10
          subset   $ 20
   ;

*--------------------------------------------------------------------------*
| Assign the Strat names and weights.                                      |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1 ) do ;
         planstra = 'HMO_A_URBAN' ;
         stratwgt = '5000' ;
      end ;
      when ( 2 ) do ;
         planstra = 'HMO_B_URBAN' ;
         stratwgt = '8000' ;
      end ;
      when ( 3 ) do ;
         planstra = 'HMO_C_URBAN' ;
         stratwgt = '15000' ;
      end ;
      when ( 4 ) do ;
         planstra = 'HMO_B_RURAL' ;
         stratwgt = '2000' ;
      end ;
      when ( 5 ) do ;
         planstra = 'HMO_C_RURAL' ;
         stratwgt = '3000' ;
      end ;
      otherwise do ;
         planstra = '???' ;
         stratwgt = '0' ;
      end ;
   end ;
   
*--------------------------------------------------------------------------*
| Assign the Plan names.                                                   |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1 )      planname = 'HMO_A' ;
      when ( 2, 4 )   planname = 'HMO_B' ;
      when ( 3, 5 )   planname = 'HMO_C' ;
      otherwise       planname = '???' ;
   end ;

*--------------------------------------------------------------------------*
| Assign the Subset Names                                                  |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1, 2, 4 ) subset = 'Northeast' ;
      when ( 3, 5 )    subset = 'South' ;
      otherwise        subset = '???' ;
   end ;
   
   putline = planstra || " " || planname || " " || stratwgt || " " || subset ;
   put putline ;
run ;

libname library ;

